##  Enter the Copied Credentials in SAP LeanIX
  1. Add the Okta integration in SAP LeanIX. For more, see Setting-up Out-of-the-Box Integrations.
  2. In the configuration, choose a name for the integration and the type of capabilities or data you want to get from Okta.
  3. Enter the credentials from the Okta admin portal that you have generated into the corresponding fields
![Entering the Necessary Credentials in SAP LeanIX](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274c4e787a441014b45decac8bdd3b5c_LowRes.png)
Entering the Necessary Credentials in SAP LeanIX
  4. Click Finish and wait for the connection to be established.


YesNo
Send
